pub trait AttachChild<C>: Sized {
// Required method
fn attach_child(self, child: C) -> Self;
}Expand description
Trait for builders that can accept a single child value. Implement this on your toolkit’s builder type when you want to opt into the default adapter.
Required Methods
fn attach_child(self, child: C) -> Self
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.